==> openshift-model-operator-4.11.2-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/ServiceCatalogAPIServerStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ServiceCatalogAPIServerStatusFluent<A extends ServiceCatalogAPIServerStatusFluent<A>> extends Fluent<A>{


    public A addToConditions(int index,OperatorCondition item);
    public A setToConditions(int index,OperatorCondition item);
    public A addToConditions(OperatorCondition... items);
    public A addAllToConditions(Collection<OperatorCondition> items);
    public A removeFromConditions(OperatorCondition... items);
    public A removeAllFromConditions(Collection<OperatorCondition> items);
    public A removeMatchingFromConditions(io.fabric8.kubernetes.api.builder.Predicate<OperatorConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<OperatorCondition> getConditions();
    public List<OperatorCondition> buildConditions();
    public OperatorCondition buildCondition(int index);
    public OperatorCondition buildFirstCondition();
    public OperatorCondition buildLastCondition();
    public OperatorCondition buildMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<OperatorConditionBuilder> predicate);
    public Boolean hasMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<OperatorConditionBuilder> predicate);
    public A withConditions(List<OperatorCondition> conditions);
    public A withConditions(OperatorCondition... conditions);
    public Boolean hasConditions();
    public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> addNewCondition();
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> addNewConditionLike(OperatorCondition item);
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,OperatorCondition item);
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> editCondition(int index);
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> editFirstCondition();
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> editLastCondition();
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> editMatchingCondition(io.fabric8.kubernetes.api.builder.Predicate<OperatorConditionBuilder> predicate);
    public A addToGenerations(int index,GenerationStatus item);
    public A setToGenerations(int index,GenerationStatus item);
    public A addToGenerations(GenerationStatus... items);
    public A addAllToGenerations(Collection<GenerationStatus> items);
    public A removeFromGenerations(GenerationStatus... items);
    public A removeAllFromGenerations(Collection<GenerationStatus> items);
    public A removeMatchingFromGenerations(io.fabric8.kubernetes.api.builder.Predicate<GenerationStatusBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildGenerations instead.
 * @return The buildable object.
 */
@Deprecated public List<GenerationStatus> getGenerations();
    public List<GenerationStatus> buildGenerations();
    public GenerationStatus buildGeneration(int index);
    public GenerationStatus buildFirstGeneration();
    public GenerationStatus buildLastGeneration();
    public GenerationStatus buildMatchingGeneration(io.fabric8.kubernetes.api.builder.Predicate<GenerationStatusBuilder> predicate);
    public Boolean hasMatchingGeneration(io.fabric8.kubernetes.api.builder.Predicate<GenerationStatusBuilder> predicate);
    public A withGenerations(List<GenerationStatus> generations);
    public A withGenerations(GenerationStatus... generations);
    public Boolean hasGenerations();
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> addNewGeneration();
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> addNewGenerationLike(GenerationStatus item);
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> setNewGenerationLike(int index,GenerationStatus item);
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> editGeneration(int index);
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> editFirstGeneration();
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> editLastGeneration();
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> editMatchingGeneration(io.fabric8.kubernetes.api.builder.Predicate<GenerationStatusBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public Integer getReadyReplicas();
    public A withReadyReplicas(Integer readyReplicas);
    public Boolean hasReadyReplicas();
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(String arg1);
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(StringBuffer arg1);

    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OperatorConditionFluent<ServiceCatalogAPIServerStatusFluent.ConditionsNested<N>>{

        
    public N and();    public N endCondition();
}
    public interface GenerationsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GenerationStatusFluent<ServiceCatalogAPIServerStatusFluent.GenerationsNested<N>>{

        
    public N and();    public N endGeneration();
}


}

==> openshift-model-operator-5.2.0-sources.jar: annotations/io/fabric8/openshift/api/model/operator/v1/ServiceCatalogAPIServerStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ServiceCatalogAPIServerStatusFluent<A extends ServiceCatalogAPIServerStatusFluent<A>> extends Fluent<A> {


    public A addToConditions(int index,OperatorCondition item);
    public A setToConditions(int index,OperatorCondition item);
    public A addToConditions(OperatorCondition... items);
    public A addAllToConditions(Collection<OperatorCondition> items);
    public A removeFromConditions(OperatorCondition... items);
    public A removeAllFromConditions(Collection<OperatorCondition> items);
    public A removeMatchingFromConditions(Predicate<OperatorConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<OperatorCondition> getConditions();
    public List<OperatorCondition> buildConditions();
    public OperatorCondition buildCondition(int index);
    public OperatorCondition buildFirstCondition();
    public OperatorCondition buildLastCondition();
    public OperatorCondition buildMatchingCondition(Predicate<OperatorConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<OperatorConditionBuilder> predicate);
    public A withConditions(List<OperatorCondition> conditions);
    public A withConditions(OperatorCondition... conditions);
    public Boolean hasConditions();
    public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> addNewCondition();
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> addNewConditionLike(OperatorCondition item);
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> setNewConditionLike(int index,OperatorCondition item);
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> editCondition(int index);
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> editFirstCondition();
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> editLastCondition();
    public ServiceCatalogAPIServerStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<OperatorConditionBuilder> predicate);
    public A addToGenerations(int index,GenerationStatus item);
    public A setToGenerations(int index,GenerationStatus item);
    public A addToGenerations(GenerationStatus... items);
    public A addAllToGenerations(Collection<GenerationStatus> items);
    public A removeFromGenerations(GenerationStatus... items);
    public A removeAllFromGenerations(Collection<GenerationStatus> items);
    public A removeMatchingFromGenerations(Predicate<GenerationStatusBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildGenerations instead.
 * @return The buildable object.
 */
@Deprecated public List<GenerationStatus> getGenerations();
    public List<GenerationStatus> buildGenerations();
    public GenerationStatus buildGeneration(int index);
    public GenerationStatus buildFirstGeneration();
    public GenerationStatus buildLastGeneration();
    public GenerationStatus buildMatchingGeneration(Predicate<GenerationStatusBuilder> predicate);
    public Boolean hasMatchingGeneration(Predicate<GenerationStatusBuilder> predicate);
    public A withGenerations(List<GenerationStatus> generations);
    public A withGenerations(GenerationStatus... generations);
    public Boolean hasGenerations();
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> addNewGeneration();
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> addNewGenerationLike(GenerationStatus item);
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> setNewGenerationLike(int index,GenerationStatus item);
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> editGeneration(int index);
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> editFirstGeneration();
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> editLastGeneration();
    public ServiceCatalogAPIServerStatusFluent.GenerationsNested<A> editMatchingGeneration(Predicate<GenerationStatusBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A withNewObservedGeneration(String arg1);
    public A withNewObservedGeneration(long arg1);
    public Integer getReadyReplicas();
    public A withReadyReplicas(Integer readyReplicas);
    public Boolean hasReadyReplicas();
    public A withNewReadyReplicas(String arg1);
    public A withNewReadyReplicas(int arg1);
    public String getVersion();
    public A withVersion(String version);
    public Boolean hasVersion();
    public A withNewVersion(String arg1);
    public A withNewVersion(StringBuilder arg1);
    public A withNewVersion(StringBuffer arg1);
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,OperatorConditionFluent<ServiceCatalogAPIServerStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


    public interface GenerationsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GenerationStatusFluent<ServiceCatalogAPIServerStatusFluent.GenerationsNested<N>> {

            public N and();
            public N endGeneration();    }


}
